@@ -15,3 +15,6 @@ class AbstractDirective(metaclass=ABCMeta):
     @property
     def directive_type(self) -> DirectiveType:
         return self._directive_type
+
+    def __hash__(self) -> int:
+        return hash(self._directive_type)
