@@ -1,6 +1,5 @@
 from abc import abstractmethod
-from typing import Optional, Tuple, Type, TypeVar
-
+from typing import Optional, Tuple, Type, TypeVar, Union
 
 from pydantic import BaseModel
 
@@ -39,6 +38,7 @@ class DocumentMetadataFields(BaseModel):
     trust_level: Optional[float]
     markers: Optional[Tuple[str, ...]]
     related_concept_id: Optional[str]
+    preview_text: Optional[str]
 
     class Config:
         extra = 'allow'  # any other extra fields will be kept
@@ -47,6 +47,8 @@ class DocumentMetadataFields(BaseModel):
 class FactMetadataFields(BaseModel):
     created_time: Optional[int]
     modified_time: Optional[int]
+    fact_confidence: Optional[Tuple[float]]
+    value_confidence: Union[float, Tuple[float, ...], None]  # same as Optional[float, Tuple[float, ...]] (pydantic bug workaround)
 
     class Config:
         extra = 'allow'  # any other extra fields will be kept
