@@ -160,7 +160,7 @@ class TalismanDocument(AbstractTalismanDocument[_Content], Generic[_Content]):
             and other._metadata == self._metadata and other._directives == self._directives
 
     def __hash__(self):
-        return hash((self._doc_id, self._content, self._metadata, self._facts, self._directives))
+        return hash((self._doc_id, self._content, self._facts, self._directives))
 
     def get_concept_related_concept(self, fact: ConceptFact, link_type_id: Optional[str] = None,
                                     filter_: Callable[[_Fact], bool] = lambda _: True) -> Iterator[ConceptFact]:
