@@ -1,10 +1,10 @@
-from typing import Any, Callable, Dict, Tuple
+from typing import Dict
 
 from typing_extensions import Literal
 
-from tdm.abstract.datamodel import AbstractFact, AbstractTalismanSpan, FactMetadata, FactStatus, FactType
+from tdm.abstract.datamodel import AbstractFact, FactType
 from tdm.datamodel.fact import RelationFact, RelationLinkValue
-from tdm.json_schema.fact.common import AbstractFactModel, PropertyLinkValueModel
+from tdm.json_schema.fact.common import AbstractFactModel, FactFactory, PropertyLinkValueModel
 
 
 class RelationFactModel(AbstractFactModel):
@@ -19,8 +19,7 @@ class RelationFactModel(AbstractFactModel):
         )
 
     @property
-    def fact_factory(self) -> Callable[[str, FactStatus, str, Any, Tuple[AbstractTalismanSpan, ...], FactMetadata],
-                                       AbstractFact]:
+    def fact_factory(self) -> FactFactory:
         return RelationFact
 
     @classmethod
